"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@botonic/core");
const hubtype_babel_api_service_1 = require("./hubtype-babel-api-service");
const isProd = process.env.NODE_ENV === 'production';
class BotonicPluginHubtypeBabel {
    constructor(options) {
        this.options = options;
        this.apiService = new hubtype_babel_api_service_1.HubtypeBabelApiService(options.projectId);
        this.includeHasSense = options.includeHasSense || false;
        this.automaticBotMessagePrefix =
            options.automaticBotMessagePrefix || '[Automatic Bot Message]';
    }
    pre(request) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            try {
                if (request.input.type == core_1.INPUT.TEXT &&
                    !request.input.payload &&
                    request.input.data &&
                    !this.isAutomaticBotMessage(request.input.data)) {
                    const sessionAuthToken = request.session._access_token;
                    const authToken = isProd ? sessionAuthToken : this.options.authToken;
                    if (!authToken) {
                        if (!sessionAuthToken) {
                            console.warn('You might be using development environment. Remember that when testing locally, adding the authToken inside plugin options is mandatory.');
                        }
                        throw new Error('Missing Authorization Token.');
                    }
                    const text = request.input.data;
                    const response = yield this.apiService.inference(text, authToken, this.includeHasSense);
                    request.input.intent = response.data['intents'][0]['label'];
                    request.input.confidence = response.data['intents'][0]['confidence'];
                    request.input.intents = response.data['intents'].map(x => ({
                        intent: x['label'],
                        confidence: x['confidence'],
                    }));
                    if (this.includeHasSense) {
                        request.input.hasSense = response.data['has_sense'];
                    }
                }
            }
            catch (e) {
                console.error('Error during inference with Hubtype Babel', e);
            }
        });
    }
    isAutomaticBotMessage(text) {
        return text
            .toLowerCase()
            .startsWith(this.automaticBotMessagePrefix.toLowerCase());
    }
}
exports.default = BotonicPluginHubtypeBabel;
//# sourceMappingURL=index.js.map